@@ -1,6 +1,8 @@
-VERSION = (1, 0, 0,)
+VERSION = (2, 4, 0)
 __version__ = '.'.join(map(str, VERSION))
 
+default_app_config = 'admin_sso.apps.AdminSSOConfig'
+
 # Do not use Django settings at module level as recommended
 try:
     from django.utils.functional import LazyObject
