@@ -1,16 +1,13 @@
+from __future__ import unicode_literals
+
 import fnmatch
+
 from django.db import models
+from django.utils.encoding import python_2_unicode_compatible
 from django.utils.translation import ugettext_lazy as _
-try:
-    from django.utils.timezone import now
-except ImportError:
-    from datetime import datetime
-    now = datetime.now
 
 from admin_sso import settings
 
-User = getattr(settings, 'AUTH_USER_MODEL', 'auth.User')
-
 
 class AssignmentManager(models.Manager):
     def for_email(self, email):
@@ -40,24 +37,26 @@ class AssignmentManager(models.Manager):
         return used_assignment
 
 
+@python_2_unicode_compatible
 class Assignment(models.Model):
     username_mode = models.IntegerField(choices=settings.ASSIGNMENT_CHOICES)
     username = models.CharField(max_length=255, blank=True)
     domain = models.CharField(max_length=255)
     copy = models.BooleanField(default=False)
     weight = models.PositiveIntegerField(default=0)
-    user = models.ForeignKey(User, null=True, blank=True)
+    user = models.ForeignKey(settings.AUTH_USER_MODEL, null=True, blank=True,
+                             on_delete=models.CASCADE)
 
     class Meta:
+        ordering = ('-weight',)
         verbose_name = _('Assignment')
         verbose_name_plural = _('Assignments')
-        ordering = ('-weight',)
 
-    def __unicode__(self):
-        return u"%s(%s) @%s" % (dict(settings.ASSIGNMENT_CHOICES)[self.username_mode], self.username, self.domain)
+    def __str__(self):
+        return "%s(%s) @%s" % (
+            dict(settings.ASSIGNMENT_CHOICES)[self.username_mode],
+            self.username,
+            self.domain,
+        )
 
     objects = AssignmentManager()
-
-
-if not settings.DJANGO_ADMIN_SSO_USE_OAUTH:
-    from .openid.models import OpenIDUser, Association, Nonce
