@@ -1,6 +1,9 @@
-from django.core.urlresolvers import reverse
 from django.contrib.auth import authenticate, login
 from django.http import HttpResponseRedirect
+try:
+    from django.urls import reverse
+except ImportError:  # Django<1.10, pragma: no cover
+    from django.core.urlresolvers import reverse
 
 from oauth2client.client import OAuth2WebServerFlow, FlowExchangeError
 
@@ -20,14 +23,13 @@ if settings.DJANGO_ADMIN_SSO_TOKEN_URI:
 if settings.DJANGO_ADMIN_SSO_REVOKE_URI:
     flow_kwargs['revoke_uri'] = settings.DJANGO_ADMIN_SSO_REVOKE_URI
 
-redirect_uri = ''  # set this after end view has been defined
-
 flow_override = None
 
 
 def start(request):
     flow = OAuth2WebServerFlow(
-        redirect_uri=request.build_absolute_uri(redirect_uri),
+        redirect_uri=request.build_absolute_uri(
+            reverse('admin:admin_sso_assignment_end')),
         **flow_kwargs)
 
     return HttpResponseRedirect(flow.step1_get_authorize_url())
@@ -36,7 +38,8 @@ def start(request):
 def end(request):
     if flow_override is None:
         flow = OAuth2WebServerFlow(
-            redirect_uri=request.build_absolute_uri(redirect_uri),
+            redirect_uri=request.build_absolute_uri(
+                reverse('admin:admin_sso_assignment_end')),
             **flow_kwargs)
     else:
         flow = flow_override
@@ -49,7 +52,7 @@ def end(request):
     except FlowExchangeError:
         return HttpResponseRedirect(reverse('admin:index'))
 
-    if credentials.id_token['verified_email']:
+    if credentials.id_token['email_verified']:
         email = credentials.id_token['email']
         user = authenticate(sso_email=email)
         if user and user.is_active:
@@ -58,6 +61,3 @@ def end(request):
 
     # if anything fails redirect to admin:index
     return HttpResponseRedirect(reverse('admin:index'))
-
-
-redirect_uri = reverse('admin:admin_sso_assignment_end')
